gpu2gpu: gpu2gpu

Description Usage Arguments Value

View source: R/helpers.r

Description

Copy the data in one GPU object to another. The objects must be of the same class (e.g. gpuvec/gpuvec and gpumat/gpumat), but they can be of different fundamental types (e.g. float/double).

Usage

1
gpu2gpu(gpu_in, gpu_out)

Arguments

gpu_in

Input.

gpu_out

Ouput.

Value

Returns NULL.


fml-fam/fmlr documentation built on Jan. 16, 2022, 9:27 a.m.